@@ -10,107 +10,29 @@ import tensorflow.keras.backend as kb
 from megnet.utils.metrics import mae, accuracy
 from megnet.utils.preprocessing import DummyScaler, Scaler
 
-from typing import Iterable, List, Dict
+from typing import Iterable, Dict
 
 logging.basicConfig()
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
 
-class GeneratorLog(Callback):
-    """
-    This callback logger.info out the MAE for train_generator and validation_generator every n_every steps.
-    The default keras training log does not contain method to rescale the results, thus is not physically
-    intuitive.
-
-    Args:
-        train_gen: (generator), yield (x, y) pairs for training
-        steps_per_train: (int) number of generator steps per training epoch
-        val_gen: (generator), yield (x, y) pairs for validation.
-        steps_per_val: (int) number of generator steps per epoch for validation data
-        y_scaler: (object) y_scaler.inverse_transform is used to convert the predicted values to its original scale
-        n_every: (int) epoch interval for showing the log
-        val_names: (list of string) variable names
-        val_units: (list of string) variable units
-        is_pa: (bool) whether it is a per-atom quantity
-    """
-
-    def __init__(self,
-                 train_gen: Iterable,
-                 steps_per_train: int = None,
-                 val_gen: Iterable = None,
-                 steps_per_val: int = None,
-                 y_scaler: Scaler = None,
-                 n_every: int = 5,
-                 val_names: List[str] = None,
-                 val_units: List[str] = None,
-                 is_pa: bool = False):
-        super().__init__()
-        self.train_gen = train_gen
-        self.val_gen = val_gen
-        self.steps_per_train = steps_per_train
-        self.steps_per_val = steps_per_val
-        self.yscaler = y_scaler
-        self.epochs = []
-        self.total_epoch = 0
-        self.n_every = n_every
-        self.val_names = val_names
-        self.val_units = val_units
-        self.is_pa = is_pa
-        if self.yscaler is None:
-            self.yscaler = DummyScaler()
-
-    def on_epoch_end(self, epoch: int, logs: Dict = None) -> None:
-        """
-        Standard keras callback interface, executed at the end of epoch
-        """
-        self.total_epoch += 1
-        if self.total_epoch % self.n_every == 0:
-            train_pred = []
-            train_y = []
-            for i in range(self.steps_per_train):
-                train_data = self.train_gen[i]
-                nb_atom = _count(np.array(train_data[0][-2]))
-                if not self.is_pa:
-                    nb_atom = np.ones_like(nb_atom)
-                pred_ = self.model.predict(train_data[0])
-                train_pred.append(self.yscaler.inverse_transform(pred_[0, :, :]) * nb_atom[:, None])
-                train_y.append(self.yscaler.inverse_transform(train_data[1][0, :, :]) * nb_atom[:, None])
-            train_mae = np.mean(np.abs(np.concatenate(train_pred, axis=0) - np.concatenate(train_y, axis=0)), axis=0)
-            logger.info("Train MAE")
-            _print_mae(self.val_names, train_mae, self.val_units)
-            val_pred = []
-            val_y = []
-            for i in range(self.steps_per_val):
-                val_data = self.val_gen[i]
-                nb_atom = _count(np.array(val_data[0][-2]))
-                if not self.is_pa:
-                    nb_atom = np.ones_like(nb_atom)
-                pred_ = self.model.predict(val_data[0])
-                val_pred.append(self.yscaler.inverse_transform(pred_[0, :, :]) * nb_atom[:, None])
-                val_y.append(self.yscaler.inverse_transform(val_data[1][0, :, :]) * nb_atom[:, None])
-            val_mae = np.mean(np.abs(np.concatenate(val_pred, axis=0) - np.concatenate(val_y, axis=0)), axis=0)
-            logger.info("Test MAE")
-            _print_mae(self.val_names, val_mae, self.val_units)
-            self.model.history.history.setdefault("train_mae", []).append(train_mae)
-            self.model.history.history.setdefault("val_mae", []).append(val_mae)
-
-
 class ModelCheckpointMAE(Callback):
     """
-    Save the best MAE model
+    Save the best MAE model with target scaler
 
     Args:
-        filepath: (string) path to save the model file with format. For example
-        `weights.{epoch:02d}-{val_mae:.6f}.hdf5` will save the corresponding epoch and val_mae in the filename
-        monitor: (string) quantity to monitor, default to "val_mae"
-        verbose: (int) 0 for no training log, 1 for only epoch-level log and 2 for batch-level log
-        save_best_only: (bool) whether to save only the best model
-        save_weights_only: (bool) whether to save the weights only excluding model structure
-        val_gen: (generator) validation generator
-        steps_per_val: (int) steps per epoch for validation generator
-        target_scaler: (object) exposing inverse_transform method to scale the output
-        period: (int) number of epoch interval for this callback
+        filepath (string): path to save the model file with format. For example
+            `weights.{epoch:02d}-{val_mae:.6f}.hdf5` will save the corresponding epoch and
+            val_mae in the filename
+        monitor (string): quantity to monitor, default to "val_mae"
+        verbose (int): 0 for no training log, 1 for only epoch-level log and 2 for batch-level log
+        save_best_only (bool): whether to save only the best model
+        save_weights_only (bool): whether to save the weights only excluding model structure
+        val_gen (generator): validation generator
+        steps_per_val (int): steps per epoch for validation generator
+        target_scaler (object): exposing inverse_transform method to scale the output
+        period (int): number of epoch interval for this callback
         mode: (string) choose from "min", "max" or "auto"
     """
 
@@ -165,7 +87,15 @@ class ModelCheckpointMAE(Callback):
                 self.best = np.Inf
 
     def on_epoch_end(self, epoch: int, logs: Dict = None) -> None:
-        logs = logs or {}
+        """
+        Codes called by the callback at the end of epoch
+        Args:
+            epoch (int): epoch id
+            logs (dict): logs of training
+
+        Returns:
+            None
+        """
         self.epochs_since_last_save += 1
         if self.epochs_since_last_save >= self.period:
             self.epochs_since_last_save = 0
@@ -177,8 +107,10 @@ class ModelCheckpointMAE(Callback):
                 stop_training = self.model.stop_training  # save stop_trainings state
                 pred_ = self.model.predict(val_data[0])
                 self.model.stop_training = stop_training
-                val_pred.append(self.target_scaler.inverse_transform(pred_[0, :, :], nb_atom[:, None]))
-                val_y.append(self.target_scaler.inverse_transform(val_data[1][0, :, :], nb_atom[:, None]))
+                val_pred.append(self.target_scaler.inverse_transform(pred_[0, :, :],
+                                                                     nb_atom[:, None]))
+                val_y.append(self.target_scaler.inverse_transform(val_data[1][0, :, :],
+                                                                  nb_atom[:, None]))
             current = self.metric(np.concatenate(val_y, axis=0), np.concatenate(val_pred, axis=0))
             filepath = self.filepath.format(**{"epoch": epoch + 1, self.monitor: current})
 
@@ -213,31 +145,43 @@ class ManualStop(Callback):
     """
 
     def on_batch_end(self, epoch: int, logs: Dict = None) -> None:
+        """
+        Codes called at the end of a batch
+        Args:
+            epoch (int): epoch id
+            logs (Dict): log dict
+
+        Returns: None
+
+        """
         if os.path.isfile('STOP'):
             self.model.stop_training = True
 
 
 class ReduceLRUponNan(Callback):
     """
-    This callback function solves a problem that when doing regression, an nan loss may occur, or the
-    loss suddenly shoot up
-    If such things happen, the model will reduce the learning rate and load the last best model during the
-    training process.
-    It has an extra function that patience for early stopping. This will move to indepedent callback in the
-    future.
+    This callback function solves a problem that when doing regression,
+    an nan loss may occur, or the loss suddenly shoot up.
+    If such things happen, the model will reduce the learning rate
+    and load the last best model during the training process.
+    It has an extra function that patience for early stopping.
+    This will move to indepedent callback in the future.
 
     Args:
-        filepath: (str) filepath for saved model checkpoint, should be consistent with checkpoint callback
-        factor: (float) a value < 1 for scaling the learning rate
-        verbose: (int) whether to show the loading event
-        patience: (int) number of steps that the val mae does not change. It is a criteria for early stopping
-        track_metric: (string) the variable to track
+        filepath (str): filepath for saved model checkpoint, should be consistent with
+            checkpoint callback
+        factor (float): a value < 1 for scaling the learning rate
+        verbose (bool): whether to show the loading event
+        patience (int): number of steps that the val mae does not change.
+            It is a criteria for early stopping
+        monitor (str): target metric to monitor
+        mode (str): min, max or auto
     """
 
     def __init__(self,
                  filepath: str = './callback/val_mae_{epoch:05d}_{val_mae:.6f}.hdf5',
                  factor: float = 0.5,
-                 verbose: int = 1,
+                 verbose: bool = True,
                  patience: int = 500,
                  monitor: str = 'val_mae',
                  mode: str = 'auto'):
@@ -266,14 +210,24 @@ class ReduceLRUponNan(Callback):
         if self.monitor not in self.variable_names:
             raise ValueError("The monitored metric should be in the name pattern")
 
-    def on_epoch_end(self, epoch: int, logs: Dict = None) -> None:
+    def on_epoch_end(self, epoch: int, logs: Dict = None):
+        """
+        Check the loss value at the end of an epoch
+        Args:
+            epoch (int): epoch id
+            logs (dict): log history
+
+        Returns: None
+
+        """
         logs = logs or {}
         loss = logs.get('loss')
         last_saved_epoch, last_metric, last_file = self._get_checkpoints()
         if last_saved_epoch is not None:
             if last_saved_epoch + self.patience <= epoch:
                 self.model.stop_training = True
-                logger.info('%s does not improve after %d, stopping the fitting...' % (self.monitor, self.patience))
+                logger.info('%s does not improve after %d, stopping '
+                            'the fitting...' % (self.monitor, self.patience))
 
         if loss is not None:
             self.losses.append(loss)
@@ -282,18 +236,21 @@ class ReduceLRUponNan(Callback):
                     logger.info("Nan loss found!")
                 self._reduce_lr_and_load(last_file)
                 if self.verbose:
-                    logger.info("Now lr is %s." % float(kb.get_value(self.model.optimizer.lr)))
+                    logger.info("Now lr is %s." % float(
+                        kb.eval(self.model.optimizer.lr)))
             else:
                 if len(self.losses) > 1:
                     if self.losses[-1] > (self.losses[-2] * 100):
                         self._reduce_lr_and_load(last_file)
                         if self.verbose:
                             logger.info(
-                                "Loss shot up from %.3f to %.3f! Reducing lr " % (self.losses[-1], self.losses[-2]))
-                            logger.info("Now lr is %s." % float(kb.get_value(self.model.optimizer.lr)))
+                                "Loss shot up from %.3f to %.3f! Reducing lr " % (
+                                    self.losses[-1], self.losses[-2]))
+                            logger.info("Now lr is %s." % float(
+                                kb.eval(self.model.optimizer.lr)))
 
     def _reduce_lr_and_load(self, last_file):
-        old_value = float(kb.get_value(self.model.optimizer.lr))
+        old_value = float(kb.eval(self.model.optimizer.lr))
         self.model.reset_states()
         self.model.optimizer.lr = old_value * self.factor
 
@@ -326,25 +283,6 @@ class ReduceLRUponNan(Callback):
             return None, None, None
 
 
-def _print_mae(target_names: List[str], maes: List[float], units: List[str]):
-    """
-    format printing the MAE for each variable
-
-    Args:
-        target_names: (list of string) variable names
-        maes:  (list of numeric) MAE values for each variable
-        units:  (list of string) units for each variable
-
-    Returns:
-          bool
-    """
-    line = []
-    for i, j, k in zip(target_names, maes, units):
-        line.append(i + ': ' + '%.4f' % j + ' ' + k)
-    logger.info(' '.join(line))
-    return True
-
-
 def _count(a: np.ndarray) -> np.ndarray:
     """
     count number of appearance for each element in a
