@@ -1,6 +1,5 @@
 """Abstract classes and utility operations for building graph representations and
 data loaders (known as Sequence objects in Keras).
-
 Most users will not need to interact with this module."""
 from abc import abstractmethod
 from operator import itemgetter
@@ -36,7 +35,6 @@ class StructureGraph(MSONable):
             This method convert a structure directly to a model input
         3. get_flat_data(self, graphs, targets)
             This method process graphs and targets pairs and output model input list.
-
     """
 
     # TODO (wardlt): Consider making "num_*_features" funcs to simplify making a MEGNet model
@@ -78,13 +76,13 @@ class StructureGraph(MSONable):
         distance.
         For state attributes, you can set structure.state = [[xx, xx]] beforehand or the algorithm would
         take default [[0, 0]]
-
         Args:
             state_attributes: (list) state attributes
             structure: (pymatgen structure)
             (dictionary)
         """
-        state_attributes = state_attributes or getattr(structure, 'state', None) or [[0, 0]]
+        state_attributes = state_attributes or getattr(structure, 'state', None) or \
+            np.array([[0.0, 0.0]], dtype='float32')
         index1 = []
         index2 = []
         bonds = []
@@ -95,9 +93,7 @@ class StructureGraph(MSONable):
             for neighbor in neighbors:
                 index2.append(neighbor['site_index'])
                 bonds.append(neighbor['weight'])
-
         atoms = self.get_atom_features(structure)
-
         if np.size(np.unique(index1)) < len(atoms):
             raise RuntimeError("Isolated atoms found in the structure")
         else:
@@ -112,10 +108,8 @@ class StructureGraph(MSONable):
     def get_atom_features(structure) -> List[int]:
         """
         Get atom features from structure, may be overwritten
-
         Args:
             structure: (Pymatgen.Structure) pymatgen structure
-
         Returns:
             List of atomic numbers
         """
@@ -135,7 +129,6 @@ class StructureGraph(MSONable):
     def graph_to_input(self, graph: Dict) -> List[np.ndarray]:
         """
         Turns a graph into model input
-
         Args:
             (dict): Dictionary description of the graph
         Return:
@@ -147,21 +140,19 @@ class StructureGraph(MSONable):
         return [expand_1st(self.atom_converter.convert(graph['atom'])),
                 expand_1st(self.bond_converter.convert(graph['bond'])),
                 expand_1st(np.array(graph['state'])),
-                expand_1st(np.array(graph['index1'])),
-                expand_1st(np.array(graph['index2'])),
-                expand_1st(np.array(gnode)),
-                expand_1st(np.array(gbond))]
+                expand_1st(np.array(graph['index1'], dtype=np.int32)),
+                expand_1st(np.array(graph['index2'], dtype=np.int32)),
+                expand_1st(np.array(gnode, dtype=np.int32)),
+                expand_1st(np.array(gbond, dtype=np.int32))]
 
     def get_flat_data(self, graphs: List[Dict], targets: List = None) -> tuple:
         """
         Expand the graph dictionary to form a list of features and targets tensors.
         This is useful when the model is trained on assembled graphs on the fly.
-
         Args:
             graphs: (list of dictionary) list of graph dictionary for each structure
             targets: (list of float or list) Optional: corresponding target
                 values for each structure
-
         Returns:
             tuple(node_features, edges_features, global_values, index1, index2, targets)
         """
@@ -213,13 +204,13 @@ class StructureGraphFixedRadius(StructureGraph):
         distance.
         For state attributes, you can set structure.state = [[xx, xx]] beforehand or the algorithm would
         take default [[0, 0]]
-
         Args:
             state_attributes: (list) state attributes
             structure: (pymatgen structure)
             (dictionary)
         """
-        state_attributes = state_attributes or getattr(structure, 'state', None) or [[0, 0]]
+        state_attributes = state_attributes or getattr(structure, 'state', None) or np.array(
+                [[0.0, 0.0]], dtype='float32')
         atoms = self.get_atom_features(structure)
         index1, index2, _, bonds = get_graphs_within_cutoff(structure, self.nn_strategy.cutoff)
 
@@ -252,7 +243,6 @@ class DummyConverter(Converter):
 class EmbeddingMap(Converter):
     """
     Convert an integer to a row vector in a feature matrix
-
     Args:
         feature_matrix: (np.ndarray) A matrix of shape (N, M)
     """
@@ -263,10 +253,8 @@ class EmbeddingMap(Converter):
     def convert(self, int_array: np.ndarray) -> np.ndarray:
         """
         convert atomic number to row vectors in the feature_matrix
-
         Args:
             int_array: (1d array) number array of length L
-
         Returns
             (matrix) L*M matrix with N the length of d and M the length of centers
         """
@@ -276,7 +264,6 @@ class EmbeddingMap(Converter):
 class GaussianDistance(Converter):
     """
     Expand distance with Gaussian basis sit at centers and with width 0.5.
-
     Args:
         centers: (np.array)
         width: (float)
@@ -289,10 +276,8 @@ class GaussianDistance(Converter):
     def convert(self, d: np.ndarray) -> np.ndarray:
         """
         expand distance vector d with given parameters
-
         Args:
             d: (1d array) distance array
-
         Returns
             (matrix) N*M matrix with N the length of d and M the length of centers
         """
@@ -300,69 +285,11 @@ class GaussianDistance(Converter):
         return np.exp(-(d[:, None] - self.centers[None, :]) ** 2 / self.width ** 2)
 
 
-class MoorseLongRange(Converter):
-    """
-    This is an attempt to implement a Moorse/long range interactomic potential like
-    distance expansion. The distance is expanded with this basis at different equilibrium
-    bond distance, r_eq. It is still a work in progress. Do not use if you do not know
-    much about the parameters
-    ref: https://en.wikipedia.org/wiki/Morse/Long-range_potential#Function
-
-    Args:
-        d_e: (float) dissociate energy
-        r_ref: (float) reference bond length
-        r_eq: (list) equilibrium bond length
-        p: (int) exponential term in the original equation, see ref
-        q: (int) exponential term in the original equaiton, see ref
-        cm: (list) long range coefficients in u_LR = Sigma_i_N (cm_i / r^i)
-        betas: (list) parameters determining the transition between long range and short range
-    """
-
-    def __init__(self, d_e=1, r_ref=2, r_eq=[1, 2, 3],
-                 p=2, q=2, cm=[1, 2, 3, 4],
-                 betas=[0.1, 0.2, 0.3, 0.4]):
-        self.d_e = d_e
-        self.r_ref = r_ref
-        self.r_eq = np.array(r_eq)
-        self.p = p
-        self.q = q
-        self.cm = np.array(cm).ravel()
-        self.n_cm = len(self.cm)
-        self.betas = np.array(betas).ravel()
-
-    def convert(self, d):
-        return self.d_e * (1 - self.u(d)[:, None] / self.u(self.r_eq)[None, :] *
-                           np.exp(-self.beta(d) * self.y(d[:, None], self.r_eq[None, :], self.p))) ** 2
-
-    def u(self, r):
-        m_i = np.arange(1, self.n_cm + 1)
-        if np.size(r) == 1:
-            return np.sum(self.cm / r ** m_i)
-        return np.sum(self.cm[None, :] / r[:, None] ** m_i[None, :], axis=1).ravel()
-
-    @staticmethod
-    def y(r, r_ref, p):
-        return (r ** p - r_ref ** p) / (r ** p + r_ref ** p)
-
-    def beta(self, r):
-        y_p_ref = self.y(r, self.r_ref, self.p)
-        y_q_ref = self.y(r, self.r_ref, self.q)
-        return (self.beta_inf[None, :] * y_p_ref[:, None] + (1 - y_p_ref[:, None]) *
-                np.sum(self.betas[None, :] * y_q_ref[:, None]
-                       ** np.arange(0, len(self.betas))[None, :], axis=1).ravel()[:, None])
-
-    @property
-    def beta_inf(self):
-        return np.log(2 * self.d_e / self.u(self.r_eq))
-
-
 class BaseGraphBatchGenerator(Sequence):
     """Base class for classes that generate batches of training data for MEGNet.
     Based on the Sequence class, which is the data loader equivalent for Keras.
-
     Implementations of this base class must implement the :meth:`_generate_inputs`,
     which generates the lists of graph descriptions for a batch.
-
     The :meth:`process_atom_features` function and related functions are used to modify
     the features for each atom, bond, and global features when creating a batch.
     """
@@ -398,10 +325,8 @@ class BaseGraphBatchGenerator(Sequence):
                             index1_temp: List[np.ndarray],
                             index2_temp: List[np.ndarray]) -> List:
         """Compile the matrices describing each graph into single matrices for the entire graph
-
         Beyond concatenating the graph descriptions, this operation updates the indices of each
         node to be sequential across all graphs so they are not duplicated between graphs
-
         Args:
             feature_list_temp ([ndarray]): List of features for each node
             connection_list_temp ([ndarray]): List of features for each connection
@@ -448,15 +373,14 @@ class BaseGraphBatchGenerator(Sequence):
             index1 += [i + offset_ind for i in ind1]
             index2 += [i + offset_ind for i in ind2]
             offset_ind += (max(ind1) + 1)
-
         # Compile the inputs in needed order
         inputs = [expand_1st(feature_list_temp),
                   expand_1st(connection_list_temp),
                   expand_1st(global_list_temp),
-                  expand_1st(index1),
-                  expand_1st(index2),
-                  expand_1st(gnode),
-                  expand_1st(gbond)]
+                  expand_1st(np.array(index1, dtype=np.int32)),
+                  expand_1st(np.array(index2, dtype=np.int32)),
+                  expand_1st(np.array(gnode, dtype=np.int32)),
+                  expand_1st(np.array(gbond, dtype=np.int32))]
         return inputs
 
     def on_epoch_end(self):
@@ -496,7 +420,6 @@ class BaseGraphBatchGenerator(Sequence):
     @abstractmethod
     def _generate_inputs(self, batch_index: int) -> tuple:
         """Get the graph descriptions for each batch
-
         Args:
              batch_index ([int]): List of indices for training batch
         Returns:
@@ -514,7 +437,6 @@ class GraphBatchGenerator(BaseGraphBatchGenerator):
     """
     A generator class that assembles several structures (indicated by
     batch_size) and form (x, y) pairs for model training.
-
     Args:
         atom_features: (list of np.array) list of atom feature matrix,
         bond_features: (list of np.array) list of bond features matrix
@@ -547,7 +469,6 @@ class GraphBatchGenerator(BaseGraphBatchGenerator):
 
     def _generate_inputs(self, batch_index: int) -> tuple:
         """Get the graph descriptions for each batch
-
         Args:
              batch_index ([int]): List of indices for training batch
         Returns:
@@ -572,7 +493,6 @@ class GraphBatchGenerator(BaseGraphBatchGenerator):
 class GraphBatchDistanceConvert(GraphBatchGenerator):
     """
     Generate batch of structures with bond distance being expanded using a Expansor
-
     Args:
         atom_features: (list of np.array) list of atom feature matrix,
         bond_features: (list of np.array) list of bond features matrix
@@ -585,7 +505,6 @@ class GraphBatchDistanceConvert(GraphBatchGenerator):
         batch_size: (int) number of samples in a batch
         is_shuffle: (bool) whether to shuffle the structure, default to True
         distance_converter: (bool) converter for processing the distances
-
     """
 
     def __init__(self,
@@ -615,11 +534,9 @@ class GraphBatchDistanceConvert(GraphBatchGenerator):
 def itemgetter_list(l, indices: List) -> tuple:
     """
     Get indices of l and return a tuple
-
     Args:
         l:  (list)
         indices: (list) indices
-
     Returns:
         (tuple)
     """
